AppColor class

Constructors

AppColor()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

error → MaterialColor
final
light → MaterialColor
final
primary → MaterialColor
final
secondary → MaterialColor
final
success → MaterialColor
final
text → MaterialColor
final
white → MaterialColor
final