EncryptSign class

Constructors

EncryptSign({required String apikey, required String commerceCode, required String secretKey})

Properties

apikey ↔ String
getter/setter pair
commerceCode ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretKey ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(Map<String, dynamic>? data) → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited