DataPayments class

Constructors

DataPayments({String? commerceCode, String? deviceId, bool? mobile, required int amount, required String order, String? subject, String? contact, int? method, List<Map<String, dynamic>>? items})

Properties

amount ↔ int
getter/setter pair
commerceCode ↔ String?
getter/setter pair
contact ↔ String?
getter/setter pair
deviceId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<Map<String, dynamic>>?
getter/setter pair
method ↔ int?
getter/setter pair
mobile ↔ bool?
getter/setter pair
order ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject ↔ String?
getter/setter pair

Methods

JSON() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited