ResponsePayment class

Constructors

ResponsePayment({required bool success, required String order, required String url, required String session, dynamic amount})
ResponsePayment.fromJson(Map<String, dynamic> json)
factory

Properties

amount → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
order → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
session → String
final
success → bool
final
url → String
final

Methods

JSON() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited